From 69b9ac2a75257a609ec828c8a90ca630319d8580 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Benedek=20L=C3=A1szl=C3=B3?= <laszlo.benedek@hu.digi.tv>
Date: Tue, 6 Jul 2010 15:15:34 +0200
Subject: [PATCH 1/2] Role support

Rolename parameter can be specified in each server's saved configuration. When specified,
issue a SET role=<rolename> command after a successfull connection to the server.
---
 pgadmin/db/pgConn.cpp                     |   18 +-
 pgadmin/dlg/dlgSelectConnection.cpp       |   12 +-
 pgadmin/dlg/dlgServer.cpp                 |    8 +-
 pgadmin/frm/frmMain.cpp                   |    1 +
 pgadmin/frm/frmStatus.cpp                 |    2 +
 pgadmin/include/db/pgConn.h               |    7 +-
 pgadmin/include/dlg/dlgSelectConnection.h |    2 +-
 pgadmin/include/schema/pgServer.h         |    6 +-
 pgadmin/pgAdmin3.cpp                      |   12 +-
 pgadmin/schema/pgRole.cpp                 |    1 +
 pgadmin/schema/pgServer.cpp               |   20 +-
 pgadmin/ui/dlgSelectConnection.xrc        |    8 +
 pgadmin/ui/dlgServer.xrc                  |   16 +-
 pgadmin/ui/xrcDialogs.cpp                 | 1086 +++++++++++++++--------------
 pgadmin/utils/sysSettings.cpp             |    1 +
 15 files changed, 648 insertions(+), 552 deletions(-)

diff --git a/pgadmin/db/pgConn.cpp b/pgadmin/db/pgConn.cpp
index 757bb46..5d16fc2 100644
--- a/pgadmin/db/pgConn.cpp
+++ b/pgadmin/db/pgConn.cpp
@@ -50,7 +50,7 @@ static void pgNoticeProcessor(void *arg, const char *message)
     ((pgConn*)arg)->Notice(message);
 }
 
-pgConn::pgConn(const wxString& server, const wxString& database, const wxString& username, const wxString& password, int port, int sslmode, OID oid)
+pgConn::pgConn(const wxString& server, const wxString& database, const wxString& username, const wxString& password, int port, const wxString& rolename, int sslmode, OID oid)
 {
     wxString msg, hostip, hostname;
 
@@ -59,6 +59,7 @@ pgConn::pgConn(const wxString& server, const wxString& database, const wxString&
     save_username = username;
     save_password = password;
     save_port = port;
+    save_rolename = rolename,
     save_sslmode = sslmode;
     save_oid = oid;
 
@@ -185,6 +186,7 @@ pgConn::pgConn(const wxString& server, const wxString& database, const wxString&
         }
     }
 
+    dbRole = rolename;
     dbHost = server;
     dbHostName = hostname;
     dbHostAddress = hostip;
@@ -196,7 +198,17 @@ pgConn::pgConn(const wxString& server, const wxString& database, const wxString&
         PQsetNoticeProcessor(conn, pgNoticeProcessor, this);
 
 
-        wxString sql=wxT("SET DateStyle=ISO;SELECT oid, pg_encoding_to_char(encoding) AS encoding, datlastsysoid\n")
+
+        wxString sql;
+        if ( rolename != wxEmptyString) {
+        	sql += wxT("SET Role=");
+			wxString role = rolename;
+			role.Replace(wxT("\\"), wxT("\\\\"));
+			role.Replace(wxT("'"), wxT("''"));
+			sql += qtString(role) + wxT(";");
+        }
+
+        sql += wxT("SET DateStyle=ISO;SELECT oid, pg_encoding_to_char(encoding) AS encoding, datlastsysoid\n")
                       wxT("  FROM pg_database WHERE ");
 
         if (oid)
@@ -256,7 +268,7 @@ void pgConn::Close()
 
 pgConn *pgConn::Duplicate()
 {
-    return new pgConn(wxString(save_server), wxString(save_database), wxString(save_username), wxString(save_password), save_port, save_sslmode, save_oid);
+    return new pgConn(wxString(save_server), wxString(save_database), wxString(save_username), wxString(save_password), save_port, save_rolename, save_sslmode, save_oid);
 }
 
 // Return the SSL mode name
diff --git a/pgadmin/dlg/dlgSelectConnection.cpp b/pgadmin/dlg/dlgSelectConnection.cpp
index d3abcc6..0d0c733 100644
--- a/pgadmin/dlg/dlgSelectConnection.cpp
+++ b/pgadmin/dlg/dlgSelectConnection.cpp
@@ -29,12 +29,14 @@ BEGIN_EVENT_TABLE(dlgSelectConnection, DialogWithHelp)
 	EVT_TEXT(CTRLID_CBSERVER,          dlgSelectConnection::OnTextChange)
 	EVT_TEXT(CTRLID_CBDATABASE,        dlgSelectConnection::OnTextChange)
 	EVT_TEXT(XRCID("txtUsername"),     dlgSelectConnection::OnTextChange)
+	EVT_TEXT(XRCID("txtRolename"),     dlgSelectConnection::OnTextChange)
     EVT_BUTTON (wxID_OK,               dlgSelectConnection::OnOK)
     EVT_BUTTON (wxID_CANCEL,           dlgSelectConnection::OnCancel)
 END_EVENT_TABLE()
 
 #define stUsername		CTRL_STATIC("stUsername")
 #define txtUsername		CTRL_TEXT("txtUsername")
+#define txtRolename		CTRL_TEXT("txtRolename")
 
 
 
@@ -64,6 +66,7 @@ DialogWithHelp(form)
 		cbServer->SetValue(settings->Read(wxT("QuickConnect/server"), wxEmptyString));
 		cbDatabase->SetValue(settings->Read(wxT("QuickConnect/database"), wxEmptyString));
 		txtUsername->SetValue(settings->Read(wxT("QuickConnect/username"), wxEmptyString));
+		txtRolename->SetValue(settings->Read(wxT("QuickConnect/rolename"), wxEmptyString));
 	}
 }
 
@@ -203,14 +206,15 @@ pgConn *dlgSelectConnection::CreateConn()
 			serv = serv.Mid(0, serv.Find(':'));
 		}
         wxString user = txtUsername->GetValue();
-		return CreateConn(serv, db, user, port, 0, true);
+        wxString role = txtRolename->GetValue();
+        return CreateConn(serv, db, user, port, role, 0, true);
     }
 }
 
-pgConn *dlgSelectConnection::CreateConn(wxString& server, wxString& dbname, wxString& username, int port, int sslmode, bool writeMRU)
+pgConn *dlgSelectConnection::CreateConn(wxString& server, wxString& dbname, wxString& username, int port, wxString& rolename, int sslmode, bool writeMRU)
 {
 	pgConn *newconn;
-	newconn = new pgConn(server, dbname, username, wxT(""), port, sslmode);
+	newconn = new pgConn(server, dbname, username, wxT(""), port, rolename, sslmode);
 	if (newconn->GetStatus() != PGCONN_OK &&
 		newconn->GetLastError().Cmp(wxString(PQnoPasswordSupplied, wxConvUTF8)) == 0)
 	{
@@ -224,7 +228,7 @@ pgConn *dlgSelectConnection::CreateConn(wxString& server, wxString& dbname, wxSt
 		if (dlg.Go() != wxID_OK)
 			return NULL;
 
-		newconn = new pgConn(server, dbname, username, dlg.GetPassword(), port, sslmode);
+		newconn = new pgConn(server, dbname, username, dlg.GetPassword(), port, rolename, sslmode);
 	}
 
 	if (newconn)
diff --git a/pgadmin/dlg/dlgServer.cpp b/pgadmin/dlg/dlgServer.cpp
index 043e87f..bf6aabe 100644
--- a/pgadmin/dlg/dlgServer.cpp
+++ b/pgadmin/dlg/dlgServer.cpp
@@ -34,6 +34,7 @@
 #define chkTryConnect   CTRL_CHECKBOX("chkTryConnect")
 #define stStorePwd      CTRL_STATIC("stStorePwd")
 #define chkStorePwd     CTRL_CHECKBOX("chkStorePwd")
+#define txtRolename     CTRL_TEXT("txtRolename")
 #define stRestore       CTRL_STATIC("stRestore")
 #define chkRestore      CTRL_CHECKBOX("chkRestore")
 #define stPassword      CTRL_STATIC("stPassword")
@@ -51,6 +52,7 @@ BEGIN_EVENT_TABLE(dlgServer, dlgProperty)
     EVT_COMBOBOX(XRCID("cbDatabase"),               dlgProperty::OnChange)
     EVT_TEXT(XRCID("txtPort")  ,                    dlgProperty::OnChange)
     EVT_TEXT(XRCID("txtUsername"),                  dlgProperty::OnChange)
+    EVT_TEXT(XRCID("txtRolename"),                  dlgProperty::OnChange)
     EVT_TEXT(XRCID("txtDbRestriction"),             dlgServer::OnChangeRestr)
     EVT_COMBOBOX(XRCID("cbSSL"),                    dlgProperty::OnChange)
     EVT_CHECKBOX(XRCID("chkStorePwd"),              dlgProperty::OnChange)
@@ -148,6 +150,7 @@ void dlgServer::OnOK(wxCommandEvent &ev)
         server->iSetSSL(cbSSL->GetCurrentSelection());
         server->iSetDatabase(cbDatabase->GetValue());
         server->iSetUsername(txtUsername->GetValue());
+        server->iSetRolename(txtRolename->GetValue());
         server->iSetStorePwd(chkStorePwd->GetValue());
         server->iSetRestore(chkRestore->GetValue());
         server->iSetDbRestriction(txtDbRestriction->GetValue().Trim());
@@ -258,6 +261,7 @@ int dlgServer::Go(bool modal)
         cbDatabase->SetValue(server->GetDatabaseName());
         txtUsername->SetValue(server->GetUsername());
         chkStorePwd->SetValue(server->GetStorePwd());
+        txtRolename->SetValue(server->GetRolename());
         chkRestore->SetValue(server->GetRestore());
         txtDbRestriction->SetValue(server->GetDbRestriction());
         txtColour->SetValue(server->GetColour());
@@ -272,6 +276,7 @@ int dlgServer::Go(bool modal)
             cbSSL->Disable();
             txtUsername->Disable();
             chkStorePwd->Disable();
+            txtRolename->Disable();
         }
     }
     else
@@ -302,7 +307,7 @@ pgObject *dlgServer::CreateObject(pgCollection *collection)
     pgServer *obj=new pgServer(GetName(), txtDescription->GetValue(), cbDatabase->GetValue(), 
         txtUsername->GetValue(), StrToLong(txtPort->GetValue()), 
         chkTryConnect->GetValue() && chkStorePwd->GetValue(), 
-        chkRestore->GetValue(), cbSSL->GetCurrentSelection());
+        txtRolename->GetValue(), chkRestore->GetValue(), cbSSL->GetCurrentSelection());
 
     obj->iSetDbRestriction(txtDbRestriction->GetValue().Trim());
 
@@ -349,6 +354,7 @@ void dlgServer::CheckChange()
                || txtUsername->GetValue() != server->GetUsername()
                || cbSSL->GetCurrentSelection() != server->GetSSL()
                || chkStorePwd->GetValue() != server->GetStorePwd()
+               || txtRolename->GetValue() != server->GetRolename()
                || chkRestore->GetValue() != server->GetRestore()
                || txtDbRestriction->GetValue() != server->GetDbRestriction()
                || txtColour->GetValue() != sColour;
diff --git a/pgadmin/frm/frmMain.cpp b/pgadmin/frm/frmMain.cpp
index 543f75d..20d3805 100644
--- a/pgadmin/frm/frmMain.cpp
+++ b/pgadmin/frm/frmMain.cpp
@@ -1043,6 +1043,7 @@ void frmMain::StoreServers()
             settings->Write(key + wxT("DiscoveryID"), server->GetDiscoveryID());
             settings->Write(key + wxT("Port"), server->GetPort());
             settings->Write(key + wxT("StorePwd"), server->GetStorePwd());
+            settings->Write(key + wxT("Rolename"), server->GetRolename());
             settings->Write(key + wxT("Restore"), server->GetRestore());
             settings->Write(key + wxT("Database"), server->GetDatabaseName());
             settings->Write(key + wxT("Username"), server->GetUsername());
diff --git a/pgadmin/frm/frmStatus.cpp b/pgadmin/frm/frmStatus.cpp
index 714df92..47d58dc 100644
--- a/pgadmin/frm/frmStatus.cpp
+++ b/pgadmin/frm/frmStatus.cpp
@@ -2212,6 +2212,7 @@ void frmStatus::OnCommit(wxCommandEvent &event)
                                        connection->GetUser(), 
                                        connection->GetPassword(), 
                                        connection->GetPort(), 
+                                       connection->GetRole(),
                                        connection->GetSslMode());
             if (tmpConn)
             {
@@ -2260,6 +2261,7 @@ void frmStatus::OnRollback(wxCommandEvent &event)
                                        connection->GetUser(), 
                                        connection->GetPassword(), 
                                        connection->GetPort(), 
+                                       connection->GetRole(),
                                        connection->GetSslMode());
             if (tmpConn)
             {
diff --git a/pgadmin/include/db/pgConn.h b/pgadmin/include/db/pgConn.h
index c0115da..f9a309b 100644
--- a/pgadmin/include/db/pgConn.h
+++ b/pgadmin/include/db/pgConn.h
@@ -81,7 +81,7 @@ typedef struct pgError {
 class pgConn
 {
 public:
-    pgConn(const wxString& server = wxT(""), const wxString& database = wxT(""), const wxString& username = wxT(""), const wxString& password = wxT(""), int port = 5432, int sslmode=0, OID oid=0);
+    pgConn(const wxString& server = wxT(""), const wxString& database = wxT(""), const wxString& username = wxT(""), const wxString& password = wxT(""), int port = 5432, const wxString& rolename = wxT(""), int sslmode=0, OID oid=0);
     ~pgConn();
 
     bool HasPrivilege(const wxString &objTyp, const wxString &objName, const wxString &priv);
@@ -109,6 +109,7 @@ public:
     pgSet *ExecuteSet(const wxString& sql);
     wxString GetUser() const { return wxString(PQuser(conn), *conv); }
     wxString GetPassword() const { return wxString(PQpass(conn), *conv); }
+    wxString GetRole() const { return dbRole; }
     wxString GetHost() const { return dbHost; }
     wxString GetHostName() const { return dbHostName; }
     wxString GetHostAddress() const { return dbHostAddress; }
@@ -153,7 +154,7 @@ protected:
 
     wxMBConv *conv;
     bool needColQuoting, utfConnectString;
-    wxString dbHost, dbHostName, dbHostAddress, dbname;
+    wxString dbRole, dbHost, dbHostName, dbHostAddress, dbname;
     OID lastSystemOID;
     OID dbOid;
 
@@ -173,7 +174,7 @@ private:
 
     wxString reservedNamespaces;
 
-    wxString save_server, save_database, save_username, save_password;
+    wxString save_server, save_database, save_username, save_password, save_rolename;
     int save_port, save_sslmode;
     OID save_oid;
 };
diff --git a/pgadmin/include/dlg/dlgSelectConnection.h b/pgadmin/include/dlg/dlgSelectConnection.h
index 2ba9226..5487a1c 100644
--- a/pgadmin/include/dlg/dlgSelectConnection.h
+++ b/pgadmin/include/dlg/dlgSelectConnection.h
@@ -24,7 +24,7 @@ public:
     wxString GetHelpPage() const;
     pgServer *GetServer() { return remoteServer; }
 	pgConn *CreateConn();
-	pgConn *CreateConn(wxString& server, wxString& dbname, wxString& username, int port, int sslmode, bool writeMRU = false);
+	pgConn *CreateConn(wxString& server, wxString& dbname, wxString& username, int port, wxString& rolename, int sslmode, bool writeMRU = false);
 	wxString GetServerName();
     wxString GetDatabase();
 
diff --git a/pgadmin/include/schema/pgServer.h b/pgadmin/include/schema/pgServer.h
index 417f598..e77eb03 100644
--- a/pgadmin/include/schema/pgServer.h
+++ b/pgadmin/include/schema/pgServer.h
@@ -38,7 +38,7 @@ extern pgServerFactory serverFactory;
 class pgServer : public pgObject
 {
 public:
-	pgServer(const wxString& newServer = wxT(""), const wxString& newDescription = wxT(""), const wxString& newDatabase = wxT(""), const wxString& newUsername = wxT(""), int newPort = 5432, bool storePwd=false, bool restore=true, int sslMode=0, const wxString &colour = wxEmptyString);
+	pgServer(const wxString& newServer = wxT(""), const wxString& newDescription = wxT(""), const wxString& newDatabase = wxT(""), const wxString& newUsername = wxT(""), int newPort = 5432, bool storePwd=false, const wxString& newRolename = wxT(""), bool restore=true, int sslMode=0, const wxString &colour = wxEmptyString);
     ~pgServer();
     int GetIconId();
 
@@ -64,6 +64,7 @@ public:
     wxString GetUsername() const { return username; }
     wxString GetPassword() const { return (password == wxEmptyString ? conn->GetPassword() : password); }
     bool GetStorePwd() const { return storePwd; }
+    wxString GetRolename() const { return rolename; }
     bool GetRestore() const { return restore; }
     wxString GetLastError() const;
 
@@ -106,6 +107,7 @@ public:
     void iSetUsername(const wxString& newVal) { username = newVal; }
     void iSetPassword(const wxString& newVal) { password = newVal; }
     void iSetStorePwd(const bool b) { storePwd = b; }
+    void iSetRolename(const wxString& newVal) { rolename = newVal; }
     void iSetRestore(const bool b) { restore = b; }
     bool SetPassword(const wxString& newVal);
     wxDateTime GetUpSince() { return upSince; }
@@ -143,7 +145,7 @@ private:
     pgConn *conn;
     long serverIndex;
     bool connected, passwordValid, autovacuumRunning;
-    wxString database, username, password, ver, error;
+    wxString database, username, password, rolename, ver, error;
     wxString lastDatabase, lastSchema, description, serviceId, discoveryId;
     wxDateTime upSince;
     int port, ssl;
diff --git a/pgadmin/pgAdmin3.cpp b/pgadmin/pgAdmin3.cpp
index 55290d2..40beb9e 100644
--- a/pgadmin/pgAdmin3.cpp
+++ b/pgadmin/pgAdmin3.cpp
@@ -450,7 +450,7 @@ bool pgAdmin3::OnInit()
             else if (cmdParser.Found(wxT("Sc"), &connstr))
             {
                 wxLogInfo(wxT("Starting in server status connect mode (-Sc)."), configFile.c_str());
-                wxString host, database, username, tmps;
+                wxString host, database, username, rolename, tmps;
                 int sslmode=0,port=0;
                 wxStringTokenizer tkn(connstr, wxT(" "), wxTOKEN_STRTOK);
                 while (tkn.HasMoreTokens())
@@ -464,6 +464,8 @@ bool pgAdmin3::OnInit()
                         continue;
                     if (str.StartsWith(wxT("user="), &username))
                         continue;
+                    if (str.StartsWith(wxT("role="), &rolename))
+                        continue;
                     if (str.StartsWith(wxT("port="), &tmps))
                     {
                         port = StrToLong(tmps);
@@ -496,7 +498,7 @@ bool pgAdmin3::OnInit()
                 winSplash->Show(false);
                 dlgSelectConnection dlg(NULL, NULL);
                 dlg.CenterOnParent();
-                conn = dlg.CreateConn(host, database, username, port, sslmode);
+                conn = dlg.CreateConn(host, database, username, port, rolename, sslmode);
             }
             else
             {
@@ -540,7 +542,7 @@ bool pgAdmin3::OnInit()
             else if (cmdParser.Found(wxT("qc"), &connstr))
             {
                 wxLogInfo(wxT("Starting in query tool connect mode (-qc)."), configFile.c_str());
-                wxString host, database, username, tmps;
+                wxString host, database, username, rolename, tmps;
                 int sslmode=0,port=0;
                 wxStringTokenizer tkn(connstr, wxT(" "), wxTOKEN_STRTOK);
                 while (tkn.HasMoreTokens())
@@ -554,6 +556,8 @@ bool pgAdmin3::OnInit()
                         continue;
                     if (str.StartsWith(wxT("user="), &username))
                         continue;
+                    if (str.StartsWith(wxT("role="), &rolename))
+                        continue;
                     if (str.StartsWith(wxT("port="), &tmps))
                     {
                         port = StrToLong(tmps);
@@ -586,7 +590,7 @@ bool pgAdmin3::OnInit()
                 winSplash->Show(false);
                 dlgSelectConnection dlg(NULL, NULL);
                 dlg.CenterOnParent();
-                conn = dlg.CreateConn(host, database, username, port, sslmode);
+                conn = dlg.CreateConn(host, database, username, port, rolename, sslmode);
             }
             else
             {
diff --git a/pgadmin/schema/pgRole.cpp b/pgadmin/schema/pgRole.cpp
index 54c0551..2685a86 100644
--- a/pgadmin/schema/pgRole.cpp
+++ b/pgadmin/schema/pgRole.cpp
@@ -306,6 +306,7 @@ void pgRole::ReassignDropOwnedTo(frmMain *form)
                      GetConnection()->GetUser(),
                      GetConnection()->GetPassword(),
                      GetConnection()->GetPort(),
+                     GetConnection()->GetRole(),
                      GetConnection()->GetSslMode());
                      
         if (conn->GetStatus() == PGCONN_OK)
diff --git a/pgadmin/schema/pgServer.cpp b/pgadmin/schema/pgServer.cpp
index 0036bfa..b1276ef 100644
--- a/pgadmin/schema/pgServer.cpp
+++ b/pgadmin/schema/pgServer.cpp
@@ -39,7 +39,7 @@
 
 #define DEFAULT_PG_DATABASE wxT("postgres")
 
-pgServer::pgServer(const wxString& newName, const wxString& newDescription, const wxString& newDatabase, const wxString& newUsername, int newPort, bool _storePwd, bool _restore, int _ssl, const wxString &_colour)
+pgServer::pgServer(const wxString& newName, const wxString& newDescription, const wxString& newDatabase, const wxString& newUsername, int newPort, bool _storePwd, const wxString& newRolename, bool _restore, int _ssl, const wxString &_colour)
 : pgObject(serverFactory, newName)
 {  
     description = newDescription;
@@ -56,6 +56,7 @@ pgServer::pgServer(const wxString& newName, const wxString& newDescription, cons
     conn = NULL;
     passwordValid=true;
     storePwd=_storePwd;
+    rolename = newRolename;
     restore=_restore;
     superUser=false;
     createPrivilege=false;
@@ -137,7 +138,7 @@ pgConn *pgServer::CreateConn(wxString dbName, OID oid)
         dbName = GetDatabaseName();
         oid = dbOid;
     }
-    pgConn *conn=new pgConn(GetName(), dbName, username, password, port, ssl, oid);
+    pgConn *conn=new pgConn(GetName(), dbName, username, password, port, rolename, ssl, oid);
 
     if (conn && conn->GetStatus() != PGCONN_OK)
     {
@@ -614,21 +615,21 @@ int pgServer::Connect(frmMain *form, bool askPassword, const wxString &pwd, bool
 
         if (database.IsEmpty())
         {
-            conn = new pgConn(GetName(), DEFAULT_PG_DATABASE, username, password, port, ssl);
+            conn = new pgConn(GetName(), DEFAULT_PG_DATABASE, username, password, port, rolename, ssl);
             if (conn->GetStatus() == PGCONN_OK)
                 database=DEFAULT_PG_DATABASE;
             else if (conn->GetStatus() == PGCONN_BAD && conn->GetLastError().Find(
                                 wxT("database \"") DEFAULT_PG_DATABASE wxT("\" does not exist")) >= 0)
             {
                 delete conn;
-                conn = new pgConn(GetName(), wxT("template1"), username, password, port, ssl);
+                conn = new pgConn(GetName(), wxT("template1"), username, password, port, rolename, ssl);
                 if (conn && conn->GetStatus() == PGCONN_OK)
                     database=wxT("template1");
             }
         }
         else
         {
-            conn = new pgConn(GetName(), database, username, password, port, ssl);
+            conn = new pgConn(GetName(), database, username, password, port, rolename, ssl);
             if (!conn)
             {
                 form->EndMsg(false);
@@ -1084,7 +1085,7 @@ pgObject *pgServerFactory::CreateObjects(pgCollection *obj, ctlTree *browser, co
     long numServers=settings->Read(wxT("Servers/Count"), 0L);
 
     long loop, port, ssl=0;
-    wxString key, servername, description, database, username, lastDatabase, lastSchema, storePwd, restore, serviceID, discoveryID, dbRestriction, colour;
+    wxString key, servername, description, database, username, lastDatabase, lastSchema, storePwd, rolename, restore, serviceID, discoveryID, dbRestriction, colour;
     pgServer *server=0;
 
     wxArrayString discoveredServers;
@@ -1105,6 +1106,7 @@ pgObject *pgServerFactory::CreateObjects(pgCollection *obj, ctlTree *browser, co
         settings->Read(key + wxT("DiscoveryID"), &discoveryID, serviceID);
         settings->Read(key + wxT("Description"), &description, wxEmptyString);
         settings->Read(key + wxT("StorePwd"), &storePwd, wxEmptyString);
+        settings->Read(key + wxT("Rolename"), &rolename, wxEmptyString);
         settings->Read(key + wxT("Restore"), &restore, wxT("true"));
         settings->Read(key + wxT("Port"), &port, 0);
         settings->Read(key + wxT("Database"), &database, wxEmptyString);
@@ -1133,7 +1135,7 @@ pgObject *pgServerFactory::CreateObjects(pgCollection *obj, ctlTree *browser, co
 #endif
 
         // Add the Server node
-        server = new pgServer(servername, description, database, username, port, StrToBool(storePwd), StrToBool(restore), ssl);
+        server = new pgServer(servername, description, database, username, port, StrToBool(storePwd), rolename, StrToBool(restore), ssl);
         server->iSetLastDatabase(lastDatabase);
         server->iSetLastSchema(lastSchema);
         server->iSetServiceID(serviceID);
@@ -1239,7 +1241,7 @@ pgObject *pgServerFactory::CreateObjects(pgCollection *obj, ctlTree *browser, co
                     // Add the item, if it looks sane
                     if (port != 0 && username != wxEmptyString)
                     {
-                        server = new pgServer(servername, description, wxT("postgres"), username, port, false, 0);
+                        server = new pgServer(servername, description, wxT("postgres"), username, port, false, rolename, 0);
                         server->iSetDiscoveryID(cnf->GetPath() + wxT("/") + version);
                         server->iSetDiscovered(true);
                         browser->AppendItem(obj->GetId(), server->GetFullName(), server->GetIconId(), -1, server);
@@ -1271,7 +1273,7 @@ pgObject *pgServerFactory::CreateObjects(pgCollection *obj, ctlTree *browser, co
                     // Add the item, if it looks sane
                     if (port != 0 && username != wxEmptyString)
                     {
-                        server = new pgServer(servername, description, wxT("edb"), username, port, false, 0);
+                        server = new pgServer(servername, description, wxT("edb"), username, port, false, rolename, 0);
                         server->iSetDiscoveryID(cnf->GetPath() + wxT("/") + version);
                         server->iSetDiscovered(true);
                         browser->AppendItem(obj->GetId(), server->GetFullName(), server->GetIconId(), -1, server);
diff --git a/pgadmin/ui/dlgSelectConnection.xrc b/pgadmin/ui/dlgSelectConnection.xrc
index 72d4647..b3a4ba5 100644
--- a/pgadmin/ui/dlgSelectConnection.xrc
+++ b/pgadmin/ui/dlgSelectConnection.xrc
@@ -20,6 +20,14 @@
       <pos>65,35d</pos>
       <size>135,-1d</size>
     </object>
+    <object class="wxStaticText" name="stRolename">
+      <label>Rolename</label>
+      <pos>5,37d</pos>
+    </object>
+    <object class="wxTextCtrl" name="txtRolename">
+      <pos>65,35d</pos>
+      <size>135,-1d</size>
+    </object>
     <object class="wxButton" name="wxID_HELP">
       <label>&amp;Help</label>
       <pos>2,65d</pos>
diff --git a/pgadmin/ui/dlgServer.xrc b/pgadmin/ui/dlgServer.xrc
index 98c1641..d8530fb 100644
--- a/pgadmin/ui/dlgServer.xrc
+++ b/pgadmin/ui/dlgServer.xrc
@@ -17,10 +17,10 @@
             <object class="wxPanel" name="pnlProperties">
               <object class="wxFlexGridSizer">
                 <cols>2</cols>
-                <rows>13</rows>
+                <rows>14</rows>
                 <vgap>5</vgap>
                 <hgap>5</hgap>
-                <growablerows>9</growablerows>
+                <growablerows>10</growablerows>
                 <growablecols>1</growablecols>
                 <object class="sizeritem">
                   <object class="wxStaticText" name="stDescription">
@@ -130,6 +130,18 @@
                   <border>4</border>
                 </object>
                 <object class="sizeritem">
+                  <object class="wxStaticText" name="stRolename">
+                    <label>Rolename</label>
+                  </object>
+                  <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxTextCtrl" name="txtRolename"/>
+                  <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
                   <object class="wxStaticText" name="stRestore">
                     <label>Restore env?</label>
                   </object>
diff --git a/pgadmin/ui/xrcDialogs.cpp b/pgadmin/ui/xrcDialogs.cpp
index 7862243..56d1038 100644
--- a/pgadmin/ui/xrcDialogs.cpp
+++ b/pgadmin/ui/xrcDialogs.cpp
@@ -1249,7 +1249,7 @@ static unsigned char xml_res_file_3[] = {
 99,116,62,10,32,32,60,47,111,98,106,101,99,116,62,10,60,47,114,101,115,
 111,117,114,99,101,62,10};
 
-static size_t xml_res_size_4 = 7981;
+static size_t xml_res_size_4 = 8021;
 static unsigned char xml_res_file_4[] = {
 60,63,120,109,108,32,118,101,114,115,105,111,110,61,34,49,46,48,34,32,101,
 110,99,111,100,105,110,103,61,34,73,83,79,45,56,56,53,57,45,49,34,63,62,
@@ -1507,115 +1507,117 @@ static unsigned char xml_res_file_4[] = {
 61,34,116,120,116,67,111,109,109,101,110,116,34,62,10,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,62,119,
 120,84,69,95,77,85,76,84,73,76,73,78,69,60,47,115,116,121,108,101,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
-101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,
-78,95,67,69,78,84,69,82,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,
-124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
-100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
-99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,
-32,110,97,109,101,61,34,115,116,67,108,117,115,116,101,114,83,101,116,34,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,
-97,98,101,108,62,85,115,101,32,114,101,112,108,105,99,97,116,105,111,110,
-60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,
-95,67,69,78,84,69,82,95,86,69,82,84,73,67,65,76,124,119,120,65,76,76,60,
-47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,
-116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
-101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,
-34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
-106,101,99,116,32,99,108,97,115,115,61,34,119,120,67,111,109,98,111,66,
-111,120,34,32,110,97,109,101,61,34,99,98,67,108,117,115,116,101,114,83,
-101,116,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,99,111,110,116,101,110,116,47,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,67,66,
-95,82,69,65,68,79,78,76,89,124,119,120,67,66,95,68,82,79,80,68,79,87,78,
-60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,
-78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,82,84,73,
-67,65,76,124,119,120,65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,
-60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,105,
+122,101,62,49,48,44,49,48,100,60,47,115,105,122,101,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,
+62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,
+69,82,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,
+70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,
+52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
-32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,47,111,
-98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,
-120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,124,
-119,120,65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,60,
-98,111,114,100,101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,32,
-32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,60,111,98,
-106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
-109,34,62,10,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,119,120,70,108,101,120,71,114,105,100,83,105,122,101,114,
-34,62,10,32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,52,60,47,99,
-111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,
-108,101,99,111,108,115,62,49,60,47,103,114,111,119,97,98,108,101,99,111,
-108,115,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
+34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
+115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,
+101,61,34,115,116,67,108,117,115,116,101,114,83,101,116,34,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
+108,62,85,115,101,32,114,101,112,108,105,99,97,116,105,111,110,60,47,108,
+97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,
+78,84,69,82,95,86,69,82,84,73,67,65,76,124,119,120,65,76,76,60,47,102,108,
+97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,
+111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
 99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
-115,115,61,34,119,120,66,117,116,116,111,110,34,32,110,97,109,101,61,34,
-119,120,73,68,95,72,69,76,80,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,108,97,98,101,108,62,72,101,108,112,60,47,108,97,98,101,108,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,
-88,80,65,78,68,124,119,120,65,76,76,60,47,102,108,97,103,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,51,60,47,98,111,
-114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
-99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
-99,108,97,115,115,61,34,115,112,97,99,101,114,34,62,10,32,32,32,32,32,32,
-32,32,32,32,32,32,60,115,105,122,101,62,48,44,48,100,60,47,115,105,122,
-101,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
-10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
-115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
+116,32,99,108,97,115,115,61,34,119,120,67,111,109,98,111,66,111,120,34,
+32,110,97,109,101,61,34,99,98,67,108,117,115,116,101,114,83,101,116,34,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,
+111,110,116,101,110,116,47,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,67,66,95,82,69,65,
+68,79,78,76,89,124,119,120,67,66,95,68,82,79,80,68,79,87,78,60,47,115,116,
+121,108,101,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
+65,76,73,71,78,95,67,69,78,84,69,82,95,86,69,82,84,73,67,65,76,124,119,
+120,65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,
+101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
+98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
+111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
+98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,
+68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,124,119,120,65,76,76,
+60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,60,98,111,114,100,101,
+114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,60,47,111,
+98,106,101,99,116,62,10,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
+108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,
+32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
+120,70,108,101,120,71,114,105,100,83,105,122,101,114,34,62,10,32,32,32,
+32,32,32,32,32,32,32,60,99,111,108,115,62,52,60,47,99,111,108,115,62,10,
+32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,99,111,108,
+115,62,49,60,47,103,114,111,119,97,98,108,101,99,111,108,115,62,10,32,32,
 32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
-34,119,120,66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,
-68,95,79,75,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,
-98,101,108,62,38,97,109,112,59,79,75,60,47,108,97,98,101,108,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,100,101,102,97,117,108,116,62,49,
-60,47,100,101,102,97,117,108,116,62,10,32,32,32,32,32,32,32,32,32,32,32,
+34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
+66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,68,95,72,69,
+76,80,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
+108,62,72,101,108,112,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
+65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+60,98,111,114,100,101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,
+32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
+32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
+112,97,99,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,115,105,
+122,101,62,48,44,48,100,60,47,115,105,122,101,62,10,32,32,32,32,32,32,32,
+32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
+60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,
+105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,119,120,66,117,116,116,111,110,
+34,32,110,97,109,101,61,34,119,120,73,68,95,79,75,34,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,
+79,75,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,100,101,102,97,117,108,116,62,49,60,47,100,101,102,97,117,108,
+116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
+69,88,80,65,78,68,124,119,120,65,76,76,60,47,102,108,97,103,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,51,60,47,98,
+111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
+32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,119,120,66,117,116,116,111,110,34,32,110,97,109,101,61,
+34,119,120,73,68,95,67,65,78,67,69,76,34,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,67,97,110,99,
+101,108,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,
 32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
 60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,76,60,
 47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
 100,101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
-32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
-32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
-114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
-98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,66,117,116,116,111,
-110,34,32,110,97,109,101,61,34,119,120,73,68,95,67,65,78,67,69,76,34,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,38,
-97,109,112,59,67,97,110,99,101,108,60,47,108,97,98,101,108,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,
-68,124,119,120,65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,60,98,111,114,100,101,114,62,51,60,47,98,111,114,100,101,
-114,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
-10,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
-32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
-84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,
-97,103,62,10,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
-32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,
-122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,60,111,98,
-106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,117,115,
-66,97,114,34,32,110,97,109,101,61,34,117,110,107,83,116,97,116,117,115,
-66,97,114,34,62,10,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,
-62,119,120,83,84,95,83,73,90,69,71,82,73,80,60,47,115,116,121,108,101,62,
-10,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
-32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
-65,76,73,71,78,95,67,69,78,84,82,69,60,47,102,108,97,103,62,10,32,32,32,
-32,32,32,32,32,60,98,111,114,100,101,114,62,51,60,47,98,111,114,100,101,
-114,62,10,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
-32,60,47,111,98,106,101,99,116,62,10,32,32,60,47,111,98,106,101,99,116,
-62,10,60,47,114,101,115,111,117,114,99,101,62,10};
+32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,
+47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,102,108,97,103,
+62,119,120,69,88,80,65,78,68,124,119,120,84,79,80,124,119,120,76,69,70,
+84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,
+32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,60,111,98,106,101,
+99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,
+62,10,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
+115,61,34,119,120,83,116,97,116,117,115,66,97,114,34,32,110,97,109,101,
+61,34,117,110,107,83,116,97,116,117,115,66,97,114,34,62,10,32,32,32,32,
+32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,83,84,95,83,73,90,69,
+71,82,73,80,60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,32,32,60,
+47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,102,108,97,103,
+62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,
+82,69,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,60,98,111,114,
+100,101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
+60,47,111,98,106,101,99,116,62,10,32,32,32,32,60,47,111,98,106,101,99,116,
+62,10,32,32,60,47,111,98,106,101,99,116,62,10,60,47,114,101,115,111,117,
+114,99,101,62,10};
 
 static size_t xml_res_size_5 = 2584;
 static unsigned char xml_res_file_5[] = {
@@ -15589,7 +15591,7 @@ static unsigned char xml_res_file_42[] = {
 99,116,62,10,32,32,60,47,111,98,106,101,99,116,62,10,60,47,114,101,115,
 111,117,114,99,101,62,10};
 
-static size_t xml_res_size_43 = 1177;
+static size_t xml_res_size_43 = 1412;
 static unsigned char xml_res_file_43[] = {
 60,63,120,109,108,32,118,101,114,115,105,111,110,61,34,49,46,48,34,32,101,
 110,99,111,100,105,110,103,61,34,73,83,79,45,56,56,53,57,45,49,34,63,62,
@@ -15625,24 +15627,35 @@ static unsigned char xml_res_file_43[] = {
 32,32,32,32,32,60,112,111,115,62,54,53,44,51,53,100,60,47,112,111,115,62,
 10,32,32,32,32,32,32,60,115,105,122,101,62,49,51,53,44,45,49,100,60,47,
 115,105,122,101,62,10,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
-32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,66,
-117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,68,95,72,69,76,
-80,34,62,10,32,32,32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,
-72,101,108,112,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,60,112,111,
-115,62,50,44,54,53,100,60,47,112,111,115,62,10,32,32,32,32,32,32,60,115,
-116,121,108,101,47,62,10,32,32,32,32,60,47,111,98,106,101,99,116,62,10,
-32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
-66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,68,95,79,75,
-34,62,10,32,32,32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,79,
-75,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,60,100,101,102,97,117,
-108,116,62,49,60,47,100,101,102,97,117,108,116,62,10,32,32,32,32,32,32,
-60,112,111,115,62,57,55,44,54,53,100,60,47,112,111,115,62,10,32,32,32,32,
-32,32,60,115,116,121,108,101,47,62,10,32,32,32,32,60,47,111,98,106,101,
-99,116,62,10,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
-61,34,119,120,66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,
-73,68,95,67,65,78,67,69,76,34,62,10,32,32,32,32,32,32,60,108,97,98,101,
-108,62,38,97,109,112,59,67,97,110,99,101,108,60,47,108,97,98,101,108,62,
-10,32,32,32,32,32,32,60,100,101,102,97,117,108,116,62,48,60,47,100,101,
+32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,
+116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,82,
+111,108,101,110,97,109,101,34,62,10,32,32,32,32,32,32,60,108,97,98,101,
+108,62,82,111,108,101,110,97,109,101,60,47,108,97,98,101,108,62,10,32,32,
+32,32,32,32,60,112,111,115,62,53,44,51,55,100,60,47,112,111,115,62,10,32,
+32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,60,111,98,106,101,
+99,116,32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,116,114,108,
+34,32,110,97,109,101,61,34,116,120,116,82,111,108,101,110,97,109,101,34,
+62,10,32,32,32,32,32,32,60,112,111,115,62,54,53,44,51,53,100,60,47,112,
+111,115,62,10,32,32,32,32,32,32,60,115,105,122,101,62,49,51,53,44,45,49,
+100,60,47,115,105,122,101,62,10,32,32,32,32,60,47,111,98,106,101,99,116,
+62,10,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
+120,66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,68,95,
+72,69,76,80,34,62,10,32,32,32,32,32,32,60,108,97,98,101,108,62,38,97,109,
+112,59,72,101,108,112,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,60,
+112,111,115,62,50,44,54,53,100,60,47,112,111,115,62,10,32,32,32,32,32,32,
+60,115,116,121,108,101,47,62,10,32,32,32,32,60,47,111,98,106,101,99,116,
+62,10,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
+120,66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,68,95,
+79,75,34,62,10,32,32,32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,
+59,79,75,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,60,100,101,102,
+97,117,108,116,62,49,60,47,100,101,102,97,117,108,116,62,10,32,32,32,32,
+32,32,60,112,111,115,62,57,55,44,54,53,100,60,47,112,111,115,62,10,32,32,
+32,32,32,32,60,115,116,121,108,101,47,62,10,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
+115,61,34,119,120,66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,
+120,73,68,95,67,65,78,67,69,76,34,62,10,32,32,32,32,32,32,60,108,97,98,
+101,108,62,38,97,109,112,59,67,97,110,99,101,108,60,47,108,97,98,101,108,
+62,10,32,32,32,32,32,32,60,100,101,102,97,117,108,116,62,48,60,47,100,101,
 102,97,117,108,116,62,10,32,32,32,32,32,32,60,112,111,115,62,49,53,48,44,
 54,53,100,60,47,112,111,115,62,10,32,32,32,32,60,47,111,98,106,101,99,116,
 62,10,32,32,60,47,111,98,106,101,99,116,62,10,60,47,114,101,115,111,117,
@@ -16086,7 +16099,7 @@ static unsigned char xml_res_file_44[] = {
 99,116,62,10,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,60,47,
 111,98,106,101,99,116,62,10,60,47,114,101,115,111,117,114,99,101,62,10};
 
-static size_t xml_res_size_45 = 11218;
+static size_t xml_res_size_45 = 11796;
 static unsigned char xml_res_file_45[] = {
 60,63,120,109,108,32,118,101,114,115,105,111,110,61,34,49,46,48,34,32,101,
 110,99,111,100,105,110,103,61,34,73,83,79,45,56,56,53,57,45,49,34,63,62,
@@ -16124,21 +16137,47 @@ static unsigned char xml_res_file_45[] = {
 101,120,71,114,105,100,83,105,122,101,114,34,62,10,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,50,60,47,99,111,108,115,
 62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,114,111,119,115,
-62,49,51,60,47,114,111,119,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+62,49,52,60,47,114,111,119,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,60,118,103,97,112,62,53,60,47,118,103,97,112,62,10,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,60,104,103,97,112,62,53,60,47,104,
 103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,
-114,111,119,97,98,108,101,114,111,119,115,62,57,60,47,103,114,111,119,97,
-98,108,101,114,111,119,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,103,114,111,119,97,98,108,101,99,111,108,115,62,49,60,47,103,
-114,111,119,97,98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
-34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
-115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,
-101,61,34,115,116,68,101,115,99,114,105,112,116,105,111,110,34,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
-108,62,78,97,109,101,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,
+114,111,119,97,98,108,101,114,111,119,115,62,49,48,60,47,103,114,111,119,
+97,98,108,101,114,111,119,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,103,114,111,119,97,98,108,101,99,111,108,115,62,49,60,47,
+103,114,111,119,97,98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
+115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,
+109,101,61,34,115,116,68,101,115,99,114,105,112,116,105,111,110,34,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,
+101,108,62,78,97,109,101,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
+119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,
+124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,
+60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
+99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
+109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
+98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,
+116,114,108,34,32,110,97,109,101,61,34,116,120,116,68,101,115,99,114,105,
+112,116,105,111,110,34,47,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
+65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,
+120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,
+108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
+116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,
+120,116,34,32,110,97,109,101,61,34,115,116,78,97,109,101,34,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
+108,62,72,111,115,116,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,
 120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,
@@ -16150,50 +16189,24 @@ static unsigned char xml_res_file_45[] = {
 101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,
 34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
 106,101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,116,
-114,108,34,32,110,97,109,101,61,34,116,120,116,68,101,115,99,114,105,112,
-116,105,111,110,34,47,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,
-76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,
-84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,
-97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,
-111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
-99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
-116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,
-116,34,32,110,97,109,101,61,34,115,116,78,97,109,101,34,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,
-62,72,111,115,116,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
-65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,
-120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,
-108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
-116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
-101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,116,114,
-108,34,32,110,97,109,101,61,34,116,120,116,78,97,109,101,34,47,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
-119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,
-69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,
-84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,
-60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,
-115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
-61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,
-61,34,115,116,80,111,114,116,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,80,111,114,116,60,47,
-108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,
-69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,
+114,108,34,32,110,97,109,101,61,34,116,120,116,78,97,109,101,34,47,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,
+62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,
+82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,
+70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,
+52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
+34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
+115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,
+101,61,34,115,116,80,111,114,116,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,80,111,114,116,60,
+47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,
+67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,
 120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,
 114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,
@@ -16362,93 +16375,93 @@ static unsigned char xml_res_file_45[] = {
 115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
 97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,
-97,109,101,61,34,115,116,82,101,115,116,111,114,101,34,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,
-82,101,115,116,111,114,101,32,101,110,118,63,60,47,108,97,98,101,108,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
-101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,
-69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,
-120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,
-114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
-114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
-67,104,101,99,107,66,111,120,34,32,110,97,109,101,61,34,99,104,107,82,101,
-115,116,111,114,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,108,97,98,101,108,47,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,99,104,101,99,107,101,100,62,49,
-60,47,99,104,101,99,107,101,100,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,
-80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,
-84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,
-82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,
-100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
-111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
-114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
-83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,
-68,98,82,101,115,116,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,108,97,98,101,108,62,68,66,32,114,101,115,116,114,
-105,99,116,105,111,110,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
-119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,
-124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,
-60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
-99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
-106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
-109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
-98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,
-116,114,108,34,32,110,97,109,101,61,34,116,120,116,68,98,82,101,115,116,
-114,105,99,116,105,111,110,34,47,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,
-119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,
-124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,
-60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
-99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
-106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
-109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
-98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,
-99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,83,101,114,118,105,
-99,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,108,97,98,101,108,62,83,101,114,118,105,99,101,60,47,108,97,98,101,
-108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
+97,109,101,61,34,115,116,82,111,108,101,110,97,109,101,34,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,
+62,82,111,108,101,110,97,109,101,60,47,108,97,98,101,108,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,
+97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,
+67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,
+71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,
+101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
 98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,
-95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,
-124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,
-47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
+60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,
+105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,
+120,116,67,116,114,108,34,32,110,97,109,101,61,34,116,120,116,82,111,108,
+101,110,97,109,101,34,47,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
+65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,
+120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,
+108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
+116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,
+120,116,34,32,110,97,109,101,61,34,115,116,82,101,115,116,111,114,101,34,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,
+97,98,101,108,62,82,101,115,116,111,114,101,32,101,110,118,63,60,47,108,
+97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,
+78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,
+76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,
+62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
+115,115,61,34,119,120,67,104,101,99,107,66,111,120,34,32,110,97,109,101,
+61,34,99,104,107,82,101,115,116,111,114,101,34,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,47,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,104,101,
+99,107,101,100,62,49,60,47,99,104,101,99,107,101,100,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,
+103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,
+84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,
+69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,
+62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
+115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,
+109,101,61,34,115,116,68,98,82,101,115,116,114,34,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,68,
+66,32,114,101,115,116,114,105,99,116,105,111,110,60,47,108,97,98,101,108,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
+106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,
+86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,
+119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,
+98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
 105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
 34,119,120,84,101,120,116,67,116,114,108,34,32,110,97,109,101,61,34,116,
-120,116,83,101,114,118,105,99,101,34,47,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,
-68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,
-65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,
-72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,
-114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
-106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,
-116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,
-116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,84,114,121,
-67,111,110,110,101,99,116,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,67,111,110,110,101,99,116,
-32,110,111,119,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,
+120,116,68,98,82,101,115,116,114,105,99,116,105,111,110,34,47,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
+119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,
+69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,
+84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,
+60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,
+115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,
+61,34,115,116,83,101,114,118,105,99,101,34,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,83,101,114,
+118,105,99,101,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
 65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,
@@ -16459,146 +16472,173 @@ static unsigned char xml_res_file_45[] = {
 10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
 116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,
 10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
-101,99,116,32,99,108,97,115,115,61,34,119,120,67,104,101,99,107,66,111,
-120,34,32,110,97,109,101,61,34,99,104,107,84,114,121,67,111,110,110,101,
-99,116,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,108,97,98,101,108,47,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,99,104,101,99,107,101,100,62,49,60,47,99,104,101,
-99,107,101,100,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,
-120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,
-119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,
-47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,
-116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
-101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,
-34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
-106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,
-84,101,120,116,34,32,110,97,109,101,61,34,115,116,67,111,108,111,117,114,
-34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-108,97,98,101,108,62,67,111,108,111,117,114,60,47,108,97,98,101,108,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
-101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,
-69,82,84,73,67,65,76,124,119,120,65,76,76,60,47,102,108,97,103,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,
-114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,116,114,
+108,34,32,110,97,109,101,61,34,116,120,116,83,101,114,118,105,99,101,34,
+47,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,
+97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,
+78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,
+76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,
+62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
+115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,
+109,101,61,34,115,116,84,114,121,67,111,110,110,101,99,116,34,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
+108,62,67,111,110,110,101,99,116,32,110,111,119,60,47,108,97,98,101,108,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
+106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,
+86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,
+119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,
+98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
+105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
+34,119,120,67,104,101,99,107,66,111,120,34,32,110,97,109,101,61,34,99,104,
+107,84,114,121,67,111,110,110,101,99,116,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,47,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,104,101,
+99,107,101,100,62,49,60,47,99,104,101,99,107,101,100,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,
+103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,
+84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,
+69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,
+62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
+115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,
+109,101,61,34,115,116,67,111,108,111,117,114,34,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,67,111,
+108,111,117,114,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
+65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,
+120,65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,
+101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
+98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,
+105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,70,108,
+101,120,71,114,105,100,83,105,122,101,114,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,50,60,47,99,
+111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,103,114,111,119,97,98,108,101,99,111,108,115,62,48,60,47,103,114,
+111,119,97,98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
 115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,119,120,70,108,101,120,71,114,105,100,83,105,122,101,114,
-34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-99,111,108,115,62,50,60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,99,
-111,108,115,62,48,60,47,103,114,111,119,97,98,108,101,99,111,108,115,62,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
+32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,116,114,108,34,32,
+110,97,109,101,61,34,116,120,116,67,111,108,111,117,114,34,47,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,
+97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,
+78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,
+76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
+100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
 10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
 106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
 109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,
-120,116,67,116,114,108,34,32,110,97,109,101,61,34,116,120,116,67,111,108,
-111,117,114,34,47,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,
-120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,
-119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,
-47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,
-101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,66,117,
+116,116,111,110,34,32,110,97,109,101,61,34,98,116,110,67,111,108,111,114,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,108,97,98,101,108,62,46,46,46,60,47,108,97,98,101,108,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
+111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,
+69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,
+120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,
+114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
+106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,
+71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,65,76,
+76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
+106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,
+116,62,10,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,
+119,120,65,76,73,71,78,95,67,69,78,84,82,69,124,119,120,65,76,76,60,47,
+102,108,97,103,62,10,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,
+62,51,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,60,47,111,98,
+106,101,99,116,62,10,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,
+32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
+120,70,108,101,120,71,114,105,100,83,105,122,101,114,34,62,10,32,32,32,
+32,32,32,32,32,32,32,60,99,111,108,115,62,52,60,47,99,111,108,115,62,10,
+32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,99,111,108,
+115,62,49,60,47,103,114,111,119,97,98,108,101,99,111,108,115,62,10,32,32,
 32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
 34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
-108,97,115,115,61,34,119,120,66,117,116,116,111,110,34,32,110,97,109,101,
-61,34,98,116,110,67,111,108,111,114,34,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,46,
-46,46,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,
-103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,
-65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,
-72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,
-114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
+66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,68,95,72,69,
+76,80,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
+108,62,72,101,108,112,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
+65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+60,98,111,114,100,101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,
 32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,
-88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,
-82,84,73,67,65,76,124,119,120,65,76,76,60,47,102,108,97,103,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,
-62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
-32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
-32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,47,
-111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
-119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,
-69,124,119,120,65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,
-32,60,98,111,114,100,101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,
-32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,60,111,
-98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,
-101,109,34,62,10,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
-108,97,115,115,61,34,119,120,70,108,101,120,71,114,105,100,83,105,122,101,
-114,34,62,10,32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,52,60,47,
-99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,
-98,108,101,99,111,108,115,62,49,60,47,103,114,111,119,97,98,108,101,99,
-111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
-32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,119,120,66,117,116,116,111,110,34,32,110,97,109,101,61,
-34,119,120,73,68,95,72,69,76,80,34,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,108,97,98,101,108,62,72,101,108,112,60,47,108,97,98,101,
-108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
+32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
+112,97,99,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,115,105,
+122,101,62,48,44,48,100,60,47,115,105,122,101,62,10,32,32,32,32,32,32,32,
+32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
+60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,
+105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,119,120,66,117,116,116,111,110,
+34,32,110,97,109,101,61,34,119,120,73,68,95,79,75,34,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,
+79,75,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,100,101,102,97,117,108,116,62,49,60,47,100,101,102,97,117,108,
+116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
 62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
 69,88,80,65,78,68,124,119,120,65,76,76,60,47,102,108,97,103,62,10,32,32,
 32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,51,60,47,98,
 111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
 101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
-32,99,108,97,115,115,61,34,115,112,97,99,101,114,34,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,60,115,105,122,101,62,48,44,48,100,60,47,115,105,122,
-101,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
-10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
-115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
-34,119,120,66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,
-68,95,79,75,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,
-98,101,108,62,38,97,109,112,59,79,75,60,47,108,97,98,101,108,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,100,101,102,97,117,108,116,62,49,
-60,47,100,101,102,97,117,108,116,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,119,120,66,117,116,116,111,110,34,32,110,97,109,101,61,
+34,119,120,73,68,95,67,65,78,67,69,76,34,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,67,97,110,99,
+101,108,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,
 32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
 60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,76,60,
 47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
 100,101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
-32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
-32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
-114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
-98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,66,117,116,116,111,
-110,34,32,110,97,109,101,61,34,119,120,73,68,95,67,65,78,67,69,76,34,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,38,
-97,109,112,59,67,97,110,99,101,108,60,47,108,97,98,101,108,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,
-68,124,119,120,65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,60,98,111,114,100,101,114,62,51,60,47,98,111,114,100,101,
-114,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
-10,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
-32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
-84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,
-97,103,62,10,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
-32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,
-122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,60,111,98,
-106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,117,115,
-66,97,114,34,32,110,97,109,101,61,34,117,110,107,83,116,97,116,117,115,
-66,97,114,34,62,10,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,
-62,119,120,83,84,95,83,73,90,69,71,82,73,80,60,47,115,116,121,108,101,62,
-10,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
-32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
-65,76,73,71,78,95,67,69,78,84,82,69,60,47,102,108,97,103,62,10,32,32,32,
-32,32,32,32,32,60,98,111,114,100,101,114,62,51,60,47,98,111,114,100,101,
-114,62,10,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
-32,60,47,111,98,106,101,99,116,62,10,32,32,60,47,111,98,106,101,99,116,
-62,10,60,47,114,101,115,111,117,114,99,101,62,10};
+32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,
+47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,102,108,97,103,
+62,119,120,69,88,80,65,78,68,124,119,120,84,79,80,124,119,120,76,69,70,
+84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,
+32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,60,111,98,106,101,
+99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,
+62,10,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
+115,61,34,119,120,83,116,97,116,117,115,66,97,114,34,32,110,97,109,101,
+61,34,117,110,107,83,116,97,116,117,115,66,97,114,34,62,10,32,32,32,32,
+32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,83,84,95,83,73,90,69,
+71,82,73,80,60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,32,32,60,
+47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,102,108,97,103,
+62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,
+82,69,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,60,98,111,114,
+100,101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
+60,47,111,98,106,101,99,116,62,10,32,32,32,32,60,47,111,98,106,101,99,116,
+62,10,32,32,60,47,111,98,106,101,99,116,62,10,60,47,114,101,115,111,117,
+114,99,101,62,10};
 
 static size_t xml_res_size_46 = 11122;
 static unsigned char xml_res_file_46[] = {
@@ -26399,142 +26439,142 @@ void InitXmlResource()
         else wxFileSystem::AddHandler(new wxMemoryFSHandler);
     }
 
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgAddFavourite.xrc"), xml_res_file_0, xml_res_size_0, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgAggregate.xrc"), xml_res_file_1, xml_res_size_1, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgCast.xrc"), xml_res_file_2, xml_res_size_2, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgCheck.xrc"), xml_res_file_3, xml_res_size_3, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgColumn.xrc"), xml_res_file_4, xml_res_size_4, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgConnect.xrc"), xml_res_file_5, xml_res_size_5, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgConversion.xrc"), xml_res_file_6, xml_res_size_6, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgDatabase.xrc"), xml_res_file_7, xml_res_size_7, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgDirectDbg.xrc"), xml_res_file_8, xml_res_size_8, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgDomain.xrc"), xml_res_file_9, xml_res_size_9, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgEditGridOptions.xrc"), xml_res_file_10, xml_res_size_10, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgExtTable.xrc"), xml_res_file_11, xml_res_size_11, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgFindReplace.xrc"), xml_res_file_12, xml_res_size_12, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgForeignKey.xrc"), xml_res_file_13, xml_res_size_13, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgFunction.xrc"), xml_res_file_14, xml_res_size_14, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgGroup.xrc"), xml_res_file_15, xml_res_size_15, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgHbaConfig.xrc"), xml_res_file_16, xml_res_size_16, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgIndex.xrc"), xml_res_file_17, xml_res_size_17, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgIndexConstraint.xrc"), xml_res_file_18, xml_res_size_18, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgJob.xrc"), xml_res_file_19, xml_res_size_19, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgLanguage.xrc"), xml_res_file_20, xml_res_size_20, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgMainConfig.xrc"), xml_res_file_21, xml_res_size_21, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgManageFavourites.xrc"), xml_res_file_22, xml_res_size_22, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgManageMacros.xrc"), xml_res_file_23, xml_res_size_23, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgOperator.xrc"), xml_res_file_24, xml_res_size_24, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgPackage.xrc"), xml_res_file_25, xml_res_size_25, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgPgpassConfig.xrc"), xml_res_file_26, xml_res_size_26, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgReassignDropOwned.xrc"), xml_res_file_27, xml_res_size_27, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgRepCluster.xrc"), xml_res_file_28, xml_res_size_28, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgRepClusterUpgrade.xrc"), xml_res_file_29, xml_res_size_29, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgRepListen.xrc"), xml_res_file_30, xml_res_size_30, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgRepNode.xrc"), xml_res_file_31, xml_res_size_31, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgRepPath.xrc"), xml_res_file_32, xml_res_size_32, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgRepSequence.xrc"), xml_res_file_33, xml_res_size_33, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgRepSet.xrc"), xml_res_file_34, xml_res_size_34, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgRepSetMerge.xrc"), xml_res_file_35, xml_res_size_35, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgRepSetMove.xrc"), xml_res_file_36, xml_res_size_36, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgRepSubscription.xrc"), xml_res_file_37, xml_res_size_37, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgRepTable.xrc"), xml_res_file_38, xml_res_size_38, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgRole.xrc"), xml_res_file_39, xml_res_size_39, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgRule.xrc"), xml_res_file_40, xml_res_size_40, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgSchedule.xrc"), xml_res_file_41, xml_res_size_41, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgSchema.xrc"), xml_res_file_42, xml_res_size_42, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgSelectConnection.xrc"), xml_res_file_43, xml_res_size_43, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgSequence.xrc"), xml_res_file_44, xml_res_size_44, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgServer.xrc"), xml_res_file_45, xml_res_size_45, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgStep.xrc"), xml_res_file_46, xml_res_size_46, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgSynonym.xrc"), xml_res_file_47, xml_res_size_47, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgTable.xrc"), xml_res_file_48, xml_res_size_48, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgTablespace.xrc"), xml_res_file_49, xml_res_size_49, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgTextSearchConfiguration.xrc"), xml_res_file_50, xml_res_size_50, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgTextSearchDictionary.xrc"), xml_res_file_51, xml_res_size_51, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgTextSearchParser.xrc"), xml_res_file_52, xml_res_size_52, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgTextSearchTemplate.xrc"), xml_res_file_53, xml_res_size_53, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgTrigger.xrc"), xml_res_file_54, xml_res_size_54, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgType.xrc"), xml_res_file_55, xml_res_size_55, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgUser.xrc"), xml_res_file_56, xml_res_size_56, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._dlgView.xrc"), xml_res_file_57, xml_res_size_57, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._frmBackup.xrc"), xml_res_file_58, xml_res_size_58, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._frmBackupGlobals.xrc"), xml_res_file_59, xml_res_size_59, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._frmBackupServer.xrc"), xml_res_file_60, xml_res_size_60, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._frmExport.xrc"), xml_res_file_61, xml_res_size_61, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._frmGrantWizard.xrc"), xml_res_file_62, xml_res_size_62, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._frmHint.xrc"), xml_res_file_63, xml_res_size_63, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._frmMaintenance.xrc"), xml_res_file_64, xml_res_size_64, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._frmOptions.xrc"), xml_res_file_65, xml_res_size_65, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._frmPassword.xrc"), xml_res_file_66, xml_res_size_66, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._frmReport.xrc"), xml_res_file_67, xml_res_size_67, _T("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$._frmRestore.xrc"), xml_res_file_68, xml_res_size_68, _T("text/xml"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgAddFavourite.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgAggregate.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgCast.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgCheck.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgColumn.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgConnect.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgConversion.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgDatabase.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgDirectDbg.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgDomain.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgEditGridOptions.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgExtTable.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgFindReplace.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgForeignKey.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgFunction.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgGroup.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgHbaConfig.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgIndex.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgIndexConstraint.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgJob.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgLanguage.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgMainConfig.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgManageFavourites.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgManageMacros.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgOperator.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgPackage.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgPgpassConfig.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgReassignDropOwned.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgRepCluster.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgRepClusterUpgrade.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgRepListen.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgRepNode.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgRepPath.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgRepSequence.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgRepSet.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgRepSetMerge.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgRepSetMove.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgRepSubscription.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgRepTable.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgRole.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgRule.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgSchedule.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgSchema.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgSelectConnection.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgSequence.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgServer.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgStep.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgSynonym.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgTable.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgTablespace.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgTextSearchConfiguration.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgTextSearchDictionary.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgTextSearchParser.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgTextSearchTemplate.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgTrigger.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgType.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgUser.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._dlgView.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._frmBackup.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._frmBackupGlobals.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._frmBackupServer.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._frmExport.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._frmGrantWizard.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._frmHint.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._frmMaintenance.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._frmOptions.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._frmPassword.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._frmReport.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$._frmRestore.xrc"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgAddFavourite.xrc"), xml_res_file_0, xml_res_size_0, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgAggregate.xrc"), xml_res_file_1, xml_res_size_1, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgCast.xrc"), xml_res_file_2, xml_res_size_2, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgCheck.xrc"), xml_res_file_3, xml_res_size_3, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgColumn.xrc"), xml_res_file_4, xml_res_size_4, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgConnect.xrc"), xml_res_file_5, xml_res_size_5, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgConversion.xrc"), xml_res_file_6, xml_res_size_6, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgDatabase.xrc"), xml_res_file_7, xml_res_size_7, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgDirectDbg.xrc"), xml_res_file_8, xml_res_size_8, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgDomain.xrc"), xml_res_file_9, xml_res_size_9, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgEditGridOptions.xrc"), xml_res_file_10, xml_res_size_10, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgExtTable.xrc"), xml_res_file_11, xml_res_size_11, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgFindReplace.xrc"), xml_res_file_12, xml_res_size_12, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgForeignKey.xrc"), xml_res_file_13, xml_res_size_13, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgFunction.xrc"), xml_res_file_14, xml_res_size_14, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgGroup.xrc"), xml_res_file_15, xml_res_size_15, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgHbaConfig.xrc"), xml_res_file_16, xml_res_size_16, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgIndex.xrc"), xml_res_file_17, xml_res_size_17, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgIndexConstraint.xrc"), xml_res_file_18, xml_res_size_18, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgJob.xrc"), xml_res_file_19, xml_res_size_19, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgLanguage.xrc"), xml_res_file_20, xml_res_size_20, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgMainConfig.xrc"), xml_res_file_21, xml_res_size_21, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgManageFavourites.xrc"), xml_res_file_22, xml_res_size_22, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgManageMacros.xrc"), xml_res_file_23, xml_res_size_23, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgOperator.xrc"), xml_res_file_24, xml_res_size_24, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgPackage.xrc"), xml_res_file_25, xml_res_size_25, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgPgpassConfig.xrc"), xml_res_file_26, xml_res_size_26, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgReassignDropOwned.xrc"), xml_res_file_27, xml_res_size_27, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgRepCluster.xrc"), xml_res_file_28, xml_res_size_28, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgRepClusterUpgrade.xrc"), xml_res_file_29, xml_res_size_29, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgRepListen.xrc"), xml_res_file_30, xml_res_size_30, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgRepNode.xrc"), xml_res_file_31, xml_res_size_31, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgRepPath.xrc"), xml_res_file_32, xml_res_size_32, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgRepSequence.xrc"), xml_res_file_33, xml_res_size_33, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgRepSet.xrc"), xml_res_file_34, xml_res_size_34, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgRepSetMerge.xrc"), xml_res_file_35, xml_res_size_35, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgRepSetMove.xrc"), xml_res_file_36, xml_res_size_36, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgRepSubscription.xrc"), xml_res_file_37, xml_res_size_37, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgRepTable.xrc"), xml_res_file_38, xml_res_size_38, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgRole.xrc"), xml_res_file_39, xml_res_size_39, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgRule.xrc"), xml_res_file_40, xml_res_size_40, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgSchedule.xrc"), xml_res_file_41, xml_res_size_41, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgSchema.xrc"), xml_res_file_42, xml_res_size_42, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgSelectConnection.xrc"), xml_res_file_43, xml_res_size_43, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgSequence.xrc"), xml_res_file_44, xml_res_size_44, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgServer.xrc"), xml_res_file_45, xml_res_size_45, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgStep.xrc"), xml_res_file_46, xml_res_size_46, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgSynonym.xrc"), xml_res_file_47, xml_res_size_47, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgTable.xrc"), xml_res_file_48, xml_res_size_48, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgTablespace.xrc"), xml_res_file_49, xml_res_size_49, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgTextSearchConfiguration.xrc"), xml_res_file_50, xml_res_size_50, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgTextSearchDictionary.xrc"), xml_res_file_51, xml_res_size_51, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgTextSearchParser.xrc"), xml_res_file_52, xml_res_size_52, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgTextSearchTemplate.xrc"), xml_res_file_53, xml_res_size_53, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgTrigger.xrc"), xml_res_file_54, xml_res_size_54, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgType.xrc"), xml_res_file_55, xml_res_size_55, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgUser.xrc"), xml_res_file_56, xml_res_size_56, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$dlgView.xrc"), xml_res_file_57, xml_res_size_57, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$frmBackup.xrc"), xml_res_file_58, xml_res_size_58, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$frmBackupGlobals.xrc"), xml_res_file_59, xml_res_size_59, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$frmBackupServer.xrc"), xml_res_file_60, xml_res_size_60, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$frmExport.xrc"), xml_res_file_61, xml_res_size_61, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$frmGrantWizard.xrc"), xml_res_file_62, xml_res_size_62, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$frmHint.xrc"), xml_res_file_63, xml_res_size_63, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$frmMaintenance.xrc"), xml_res_file_64, xml_res_size_64, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$frmOptions.xrc"), xml_res_file_65, xml_res_size_65, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$frmPassword.xrc"), xml_res_file_66, xml_res_size_66, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$frmReport.xrc"), xml_res_file_67, xml_res_size_67, _T("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp$frmRestore.xrc"), xml_res_file_68, xml_res_size_68, _T("text/xml"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgAddFavourite.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgAggregate.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgCast.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgCheck.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgColumn.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgConnect.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgConversion.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgDatabase.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgDirectDbg.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgDomain.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgEditGridOptions.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgExtTable.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgFindReplace.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgForeignKey.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgFunction.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgGroup.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgHbaConfig.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgIndex.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgIndexConstraint.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgJob.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgLanguage.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgMainConfig.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgManageFavourites.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgManageMacros.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgOperator.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgPackage.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgPgpassConfig.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgReassignDropOwned.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgRepCluster.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgRepClusterUpgrade.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgRepListen.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgRepNode.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgRepPath.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgRepSequence.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgRepSet.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgRepSetMerge.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgRepSetMove.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgRepSubscription.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgRepTable.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgRole.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgRule.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgSchedule.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgSchema.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgSelectConnection.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgSequence.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgServer.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgStep.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgSynonym.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgTable.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgTablespace.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgTextSearchConfiguration.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgTextSearchDictionary.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgTextSearchParser.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgTextSearchTemplate.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgTrigger.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgType.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgUser.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$dlgView.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$frmBackup.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$frmBackupGlobals.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$frmBackupServer.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$frmExport.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$frmGrantWizard.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$frmHint.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$frmMaintenance.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$frmOptions.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$frmPassword.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$frmReport.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp$frmRestore.xrc"));
 }
diff --git a/pgadmin/utils/sysSettings.cpp b/pgadmin/utils/sysSettings.cpp
index c441495..c67ed27 100644
--- a/pgadmin/utils/sysSettings.cpp
+++ b/pgadmin/utils/sysSettings.cpp
@@ -52,6 +52,7 @@ sysSettings::sysSettings(const wxString& name) : wxConfig(name)
             moveStringValue(wxT("Servers/Server%d"), wxT("Servers/%d/Server"), i);
             moveStringValue(wxT("Servers/ServiceId%d"), wxT("Servers/%d/ServiceId"), i);
             moveStringValue(wxT("Servers/StorePWD%d"), wxT("Servers/%d/StorePWD"), i);
+            moveStringValue(wxT("Servers/Rolename%d"), wxT("Servers/%d/Rolename"), i);
             moveStringValue(wxT("Servers/Username%d"), wxT("Servers/%d/Username"), i);
             moveLongValue(wxT("Servers/Port%d"), wxT("Servers/%d/Port"), i);
             moveLongValue(wxT("Servers/SSL%d"), wxT("Servers/%d/SSL"), i);
-- 
1.7.1

